@@ -18,6 +18,7 @@ html_dependency_virtualselect <- function() {
 #' @param group_by Variable identifying groups to use option group feature.
 #' @param description Optional variable allowing to show a text under the labels.
 #' @param alias Optional variable containing text to use with search feature.
+#' @param classNames Optional variable containing class names to customize specific options.
 #'
 #' @return A `list` to use as `choices` argument of [virtualSelectInput()].
 #' @export
@@ -30,14 +31,16 @@ prepare_choices <- function(.data,
                             value,
                             group_by = NULL,
                             description = NULL,
-                            alias = NULL) {
+                            alias = NULL,
+                            classNames = NULL) {
   args <- lapply(
     X = enexprs(
       label = label,
       value = value,
       group_by = group_by,
       description = description,
-      alias = alias
+      alias = alias,
+      classNames = classNames
     ),
     FUN = eval_tidy,
     data = as.data.frame(.data)
@@ -98,6 +101,11 @@ prepare_choices <- function(.data,
 #' @note State of the menu (open or close) is accessible server-side through the input value:
 #'  `input$<inputId>_open`, which can be `TRUE` (opened) or `FALSE` (closed) or `NULL` (when initialized).
 #'
+#' @note For arguments that accept a function (`onServerSearch`, `labelRenderer`), only a string with a function name
+#' is accepted. The function must be defined outside of any `$(document).ready({...})` javascript block. For examples, see the
+#' documentation for [onServerSearch](https://sa-si-dev.github.io/virtual-select/#/examples?id=server-search)
+#' and [labelRenderer](https://sa-si-dev.github.io/virtual-select/#/examples?id=add-imageicon).
+#'
 #' @seealso
 #'  * [demoVirtualSelect()] for demo apps
 #'  * [updateVirtualSelect()] for updating from server
@@ -109,6 +117,7 @@ prepare_choices <- function(.data,
 #' @importFrom jsonlite toJSON
 #'
 #' @example inst/examples/virtual-select/default/app.R
+#' @example examples/virtual-select-funcs.R
 virtualSelectInput <- function(inputId,
                                label,
                                choices,
@@ -259,8 +268,11 @@ updateVirtualSelect <- function(inputId,
 #' # Prepare choices from a data.frame
 #' demoVirtualSelect("prepare-choices")
 #'
+#' # Theming with bslib
+#' demoVirtualSelect("bslib-theming")
+#'
 #' }
-demoVirtualSelect <- function(name = c("default", "update", "choices-format", "prepare-choices")) {
+demoVirtualSelect <- function(name = c("default", "update", "choices-format", "prepare-choices", "bslib-theming")) {
   name <- match.arg(name )
   runApp(
     shinyAppFile(
